@@ -46,7 +46,7 @@
 static QLoggingCategory category("org.kde.kdesu");
 
 QByteArray command;
-const char *Version = "1.0";
+const char *Version = PROJECT_VERSION;
 
 // NOTE: if you change the position of the -u switch, be sure to adjust it
 // at the beginning of main()
@@ -89,7 +89,7 @@ int main(int argc, char *argv[])
             "jansen@kde.org", "http://www.stack.nl/~geertj/");
     aboutData.addAuthor(i18n("Pietro Iglio"), i18n("Original author"),
             "iglio@fub.it");
-    aboutData.setProgramIconName("dialog-password");
+    app.setWindowIcon(QIcon::fromTheme("dialog-password"));
 
     KAboutData::setApplicationData(aboutData);
 
